corner_encroaches

Function corner_encroaches 

fn corner_encroaches(
    ix: f32,
    iy: f32,
    cx: f32,
    cy: f32,
    r: LayoutSize,
    sx: f32,
    sy: f32,
) -> bool
Check if a rounded corner region from a rect whose corner is at (cx, cy) with radius r extends into the intersection rect at corner (ix, iy). (sx, sy) are direction signs toward the rect interior from this corner.