pub struct ClipEntry {
pub handle: Handle<ClipIntern>,
pub spatial_node_index: SpatialNodeIndex,
pub clip_rect: RectKey,
}Expand description
A reference to an interned clip paired with the spatial node that positions it.
Fields
handle: Handle<ClipIntern>spatial_node_index: SpatialNodeIndexclip_rect: RectKeyTrait Implementations
Sourceimpl MallocSizeOf for ClipEntry
impl MallocSizeOf for ClipEntry
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
impl Copy for ClipEntry
impl Eq for ClipEntry
impl StructuralPartialEq for ClipEntry