pub enum ClipSpaceConversion {
Local,
ScaleOffset(ScaleOffset),
Transform(LayoutToVisTransform),
}Expand description
A helper struct for converting between coordinate systems of clip sources and primitives.
Note that the variants don’t represent the same transformation because depending on the situation we either map between the clip and primitive spaces or project them both to visibility space.
Variants
Local
The clip and the clipped primitive are in the same coordinate space.
ScaleOffset(ScaleOffset)
The clip and the clipped primitive are in the same coordinate system.
This variant represents the transform from the clip’s local space to the clipped primitive’s local space.
Transform(LayoutToVisTransform)
The clip and the clipped primitive are in different coordinate system.
This Variant represents the transform from the clip’s local space to the visibility space.
Implementations
Sourceimpl ClipSpaceConversion
impl ClipSpaceConversion
Sourcepub fn new(
prim_spatial_node_index: SpatialNodeIndex,
clip_spatial_node_index: SpatialNodeIndex,
visibility_spatial_node_index: SpatialNodeIndex,
spatial_tree: &SpatialTree,
) -> Self
pub fn new( prim_spatial_node_index: SpatialNodeIndex, clip_spatial_node_index: SpatialNodeIndex, visibility_spatial_node_index: SpatialNodeIndex, spatial_tree: &SpatialTree, ) -> Self
Construct a new clip space converter between two spatial nodes.
fn to_flags(&self) -> ClipNodeFlags