pub fn intersect_rounded_rects(
rect_a: LayoutRect,
radius_a: BorderRadius,
rect_b: LayoutRect,
radius_b: BorderRadius,
) -> Option<(LayoutRect, BorderRadius)>Expand description
Try to intersect two ClipMode::Clip rounded rects (in the same coordinate space) into a single rounded rect. Returns None if the two rounded rects cannot be combined (e.g. their curved regions overlap in a way that can’t be represented by a single rounded rect).